==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Top/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Categoria");
define("_LVOTES","votos");
define("_HITS","Hits");
define("_TOPWELCOME","Bem-Vindo ao TOP de");
define("_READSTORIES","primeiras notcias mais lidas");
define("_COMMENTEDSTORIES","primeiras notcias mais comentadas");
define("_ACTIVECAT","primeiras categorias mais ativas");
define("_READSECTION","primeiros artigos mais lidos nas sees especiais");
define("_NEWSSUBMITTERS","primeiros usurios mais ativos no envio de notcias e que so pulicadas");
define("_NEWSSENT","enviar notcia");
define("_VOTEDPOLLS","primeiras pesquisas mais votadas");
define("_MOSTACTIVEAUTHORS","primeiros autores mais ativos");
define("_NEWSPUBLISHED","notcias publicadas");
define("_READREVIEWS","primeiras revises mais lidas");
define("_DOWNLOADEDFILES","primeiros arquivos do download");
define("_MOSTREADPAGES","most read pages");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Top/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Categoria");
define("_LVOTES","votos");
define("_HITS","Hits");
define("_TOPWELCOME","Bem-Vindo ao TOP de");
define("_READSTORIES","primeiras notcias mais lidas");
define("_COMMENTEDSTORIES","primeiras notcias mais comentadas");
define("_ACTIVECAT","primeiras categorias mais ativas");
define("_READSECTION","primeiros artigos mais lidos nas sees especiais");
define("_NEWSSUBMITTERS","primeiros usurios mais ativos no envio de notcias e que so pulicadas");
define("_NEWSSENT","enviar notcia");
define("_VOTEDPOLLS","primeiras pesquisas mais votadas");
define("_MOSTACTIVEAUTHORS","primeiros autores mais ativos");
define("_NEWSPUBLISHED","notcias publicadas");
define("_READREVIEWS","primeiras revises mais lidas");
define("_DOWNLOADEDFILES","primeiros arquivos do download");
define("_MOSTREADPAGES","most read pages");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>
